/// \file mil1553ud_library.h
/// \brief библиотека взаимодействия
/// заголовки функций
#ifndef MIL1553UD_LIBRARY_H
#define MIL1553UD_LIBRARY_H

#include "mil1553ud_cmd.h"
#include "mil1553ud_regs.h"

#include <stdint.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <fcntl.h>
#include <time.h>
#include <unistd.h>
#include <strings.h>
#include <errno.h>
#include <ctype.h>
#include <time.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/time.h>
#include <sys/ioctl.h>  /* ioctl */
#include <dirent.h>
#include <string.h>
#include <sys/param.h>

#ifdef __cplusplus
extern "C" {
#endif

/// \remark Старые функции имеют префикс mil1553ud_
/// Новые функции имеют префикс mil1553_

/// /// /// /// /// /// /// /// /// /// /// ///
/// \remark МАКРОБИБЛИОТЕКА MIL1553. ТИПЫ ДАННЫХ и ОБЪЯВЛЕНИЯ.
/// /// /// /// /// /// /// /// /// /// /// ///

/// \brief код значения - хорошо
#define GOOD_CODE                       0
/// \brief код значения - плохо
#define BAD_CODE                        -1

/// \brief длина имени канала
#define CHANNEL_NAME_LENGTH             30

#define MIL1553_OFF     0
#define MIL1553_ON      (~MIL1553_OFF)

///
/// \brief The TMil1553Channel struct информация о канале
///
struct TMil1553Channel {
    char mNameChannel[CHANNEL_NAME_LENGTH];             ///< полное имя канала
    int  mFD;                                           ///< дескриптор файла
};

///
/// \brief The TMil1553Device struct информация о девайсе
///
struct TMil1553Device {
    struct TMil1553Channel  mDev;                       ///< канал, олицетворяющий весь девайс
    VERSION mInfo;                                      ///< инфо о девайсе
};

/// /// /// /// /// /// /// /// /// /// /// ///
/// \remark МАКРОБИБЛИОТЕКА MIL1553. ФУНКЦИИ.
/// /// /// /// /// /// /// /// /// /// /// ///

#ifdef __cplusplus

/// \brief mil1553_open открыть канал
/// \param _file имя файла символьного устройства канала
/// \return дескриптор открытого канала
#define mil1553_open(_file) \
    ::open(_file, O_RDWR)

/// \brief mil1553_openfl открыть канал
/// \param _file имя файла символьного устройства канала
/// \param _oflags флаги-опции открытия
/// \return дескриптор открытого канала
#define mil1553_openfl(_file, _oflags) \
    ::open(_file, _oflags)

/// \brief mil1553_close закрыть канал
/// \param _fd дескриптор открытого канала
#define mil1553_close(_fd) \
    ::close(_fd)

#else

/// \brief mil1553_open открыть канал
/// \param _file имя файла символьного устройства канала
/// \return дескриптор открытого канала
#define mil1553_open(_file) \
    open(_file, O_RDWR)

/// \brief mil1553_openfl открыть канал
/// \param _file имя файла символьного устройства канала
/// \param _oflags флаги-опции открытия
/// \return дескриптор открытого канала
#define mil1553_openfl(_file, _oflags) \
    open(_file, _oflags)

/// \brief mil1553_close закрыть канал
/// \param _fd дескриптор открытого канала
#define mil1553_close(_fd) \
    close(_fd)

#endif

/// \brief размер блока дма mil1553
#define MIL1553_DMA_BLOCK_SIZE      128
///
/// \brief The TMIL1553_DMA_BLOCK struct блок дма mil1553
///
struct TMIL1553_DMA_BLOCK {
    unsigned char mData[MIL1553_DMA_BLOCK_SIZE];        ///< содержимое блока
};

/// \brief максимальный размер контейнера блоков дма mil1553
#define MIL1553_DMA_CONTAINER_BLOCKS_MAX_SIZE   128
///
/// \brief The MIL1553_DMA_CONTAINER_BLOCKS struct контейнер блоков дма mil1553
///
struct MIL1553_DMA_CONTAINER_BLOCKS {
    struct TMIL1553_DMA_BLOCK mBlocks[MIL1553_DMA_CONTAINER_BLOCKS_MAX_SIZE];   ///< блоки ДМА
    int mCount; ///< кол-во блоков
};

///
/// \brief mil1553_readDma Чтение данных (блоков) из ДМА буфера канала
/// \param fd дескриптор канала
/// \param container контейнер блоков ДМА
/// \return результат операции
///
unsigned int mil1553_readDma(int fd, struct MIL1553_DMA_CONTAINER_BLOCKS* container);

///
/// \brief mil1553_manChannel Вкл./выкл. канала
/// \param fd дескриптор канала
/// \param op MIL_DEV_CHANNEL_ON, MIL_DEV_CHANNEL_OFF
/// \return результат операции
///
unsigned int mil1553_manChannel(int fd, unsigned int op);

///
/// \brief mil1553_setRole Выбор роли (режима) канала КШ, ОУ, МШ, ОУМШ
/// \param fd дескриптор канала
/// \param role роль (режим)
/// \return результат операции
///
unsigned int mil1553_setRole(int fd, unsigned int role);

///
/// \brief getCountChannels получить кол-во каналов со всех девайсов
/// \return кол-во каналов
///
int mil1553_getCountChannels(void);

///
/// \brief mil1553_getCountDevices получить количество девайсов
/// \return кол-во девайсов
///
int mil1553_getCountDevices(void);

///
/// \brief mil1553_getArrayDevices получить массив описателей девайсов
/// выделяет память под массив
/// \param devices указатель на массив описателей девайсов
/// \param length указатель на длину массива
///
void mil1553_getArrayDevices(struct TMil1553Device** devices, int* length);

///
/// \brief mil1553_getNumberDevice получить номер устройства, к которому принадлежит канал
/// \param channel канал
/// \return номер устройства
///
int mil1553_getNumberDevice(struct TMil1553Channel * channel);

///
/// \brief mil1553_getArrayChannels получить список каналов всех устройств
/// \param channels каналы
/// \param length размер массива
///
void mil1553_getArrayChannels(struct TMil1553Channel **channels, int *length);

///
/// \brief mil1553_getArrayChannelsByDevice Получить список каналов у заданного девайса
/// \param dev информация о девайсе
/// \param channels каналы
/// \param length размер массива
///
void mil1553_getArrayChannelsByDevice(struct TMil1553Device* dev, struct TMil1553Channel **channels, int *length);

///
/// \brief mil1553_writeReg записать значение регистра
/// \param fd дескриптор канала
/// \param reg инфо о регистре
/// \return результат операции
///
unsigned int mil1553_writeReg(int fd, SADDR_DATA* reg);

///
/// \brief mil1553_readReg прочитать значение регистра
/// \param fd дескриптор канала
/// \param reg инфо о регистре
/// \return результат операции
///
unsigned int mil1553_readReg(int fd, SADDR_DATA* reg);

///
/// \brief mil1553_modifyReg изменить заданные биты регистра
/// \param fd дескриптор канала
/// \param reg инфо о регистре
/// \return результат операции
///
unsigned int mil1553_modifyReg(int fd, SADDR_DATA_BIT_MASK* reg);

///
/// \brief mil1553_getDeviceInfo получить информацию о канале и плате
/// \param fd дескриптор канала
/// \param info инфо о канале и плате
/// \return результат операции
///
unsigned int mil1553_getDeviceInfo(int fd, VERSION* info);

///
/// \brief mil1553_getDriverVersion получить версию драйверу
/// \param fd дескриптор канала
/// \param version версия драйвера
/// \return результат операции
///
unsigned int mil1553_getDriverVersion(int fd, unsigned int* version);

///
/// \brief mil1553_getDevicePciInfo получить информацию о pci локации платы
/// \param fd дескриптор канала
/// \param pciInfo информация о pci локации платы
/// \return результат операции
///
unsigned int mil1553_getDevicePciInfo(int fd, PCI_LOCATION* pciInfo);

///
/// \brief mil1553_clearDma Сброс ДМА
/// \param fd дескриптор канала
/// \return результат операции
///
unsigned int mil1553_clearDma(int fd);

///
/// \brief mil1553_manDma управление ДМА
/// \param fd дескриптор канала
/// \param op 0 - выкл, !0 - вкл
/// \return результат операции
///
unsigned int mil1553_manDma(int fd, int op);

///
/// \brief mil1553_switchBus Выбор шины А и/или Б
/// \param fd дескриптор канала
/// \param bus шина - MIL_BUS_A_EN, MIL_BUS_B_EN
/// \return результат операции
///
unsigned int mil1553_switchBus(int fd, unsigned int bus);

///
/// \brief The EMil1553BcTypeDataRam enum тип озу контроллера шины
///
enum EMil1553BcTypeDataRam {
    Mil1553BcTypeInstructions = 0,   ///< инструкции кш
    Mil1553BcTypeOperations,         ///< операции кш
    Mil1553BcTypeData                ///< данные кш
};

/// \brief максимальный размер массива слов озу кш не данные
#define MIL1553_BC_MAX_SIZE_RAM_NONDATA     4096
/// \brief максимальный размер массива слов озу кш данные
#define MIL1553_BC_MAX_SIZE_RAM_DATA        (4096*2)

/// \brief ошибка записи в BC RAM - ошибка максимальной длины данных
#define MIL1553_BC_WRT_DATA_RAM_ERROR_MAX_LEN       -2
/// \brief ошибка записи в BC RAM - ошибка записи одного блока RAM
#define MIL1553_BC_WRT_DATA_RAM_ERROR_BAD_WRT       -3
/// \brief ошибка записи в BC RAM - ошибка чтения одного блока RAM
#define MIL1553_BC_WRT_DATA_RAM_ERROR_BAD_RD        -4
/// \brief ошибка записи в BC RAM - ошибка контроля записи одного блока RAM
#define MIL1553_BC_WRT_DATA_RAM_ERROR_BAD_CHECK     -5

///
/// \brief mil1553_bc_writeDataToRam запись данных в RAM контроллера шины
/// \param fd дескриптор канала
/// \param type тип озу контроллера шины
/// \param data данные (массив)
/// \param length размер массива
/// \return результат операции
///
unsigned int mil1553_bc_writeDataToRam(int fd, enum EMil1553BcTypeDataRam type, unsigned int* data, int length);

///
/// \brief mil1553_rt_manSubaddresses Разрешение подадресов ОУ на приём/передачу
/// \param fd дескриптор канала
/// \param direction направление MIL_RT_BUF_RECEIVE, MIL_RT_BUF_TRANSMIT
/// \param subadr_mask маска подадресов (1 - изменять подадрес, 0 - не изменять поадрес) (с 1 по 30 подадрес)
/// \param action_mask маска действий (1 - разрешить, 0 - запретить) (с 1 по 30 подадрес)
/// \return результат операции
///
unsigned int mil1553_rt_manSubaddresses(int fd, unsigned int direction, unsigned int subadr_mask, unsigned int action_mask);

///
/// \brief mil1553_rt_setAddress установить адрес ОУ
/// \param fd дескриптор канала
/// \param address адрес ОУ
/// \return результат операции
///
unsigned int mil1553_rt_setAddress(int fd, unsigned char address);

///
/// \brief mil1553_rt_manSubadressBufferMode управление режимом буфера ОУ на передачу
/// \param fd дескриптор канала
/// \param subaddress подадрес
/// \param mode режим буфера MIL_RT_MODE_PROG, MIL_RT_MODE_HRDW
/// \return результат операции
///
unsigned int mil1553_rt_manSubadressTransmitBufferMode(int fd, unsigned char subaddress, unsigned int mode);

///
/// \brief mil1553_rt_manSubaddressTransmitBufferReady управление готовностью буфера ОУ на передачу
/// \param fd дескриптор канала
/// \param subaddress подадрес
/// \param cmd_buf команды управления буферами
/// \return результат операции
///
unsigned int mil1553_rt_manSubaddressTransmitBufferReady(int fd, unsigned char subaddress, unsigned int cmd_buf);

/// \brief кол-ва слов в подадресе
#define MIL1553_RT_SUBADDRESS_COUNT_WORDS   32

///
/// \brief The TRtSubaddressData struct данные в подадресе
///
struct TRtSubaddressData {
    unsigned short mWords[MIL1553_RT_SUBADDRESS_COUNT_WORDS];   ///< 16-битные слова
    int mCount;                                                 ///< кол-во слов
};

///
/// \brief mil1553_rt_writeDataToSubaddressTransmit запись данных в подадрес отправного буфера ОУ
/// \param fd дескриптор канала
/// \param num_buf номер аппаратного буфера MIL_RT_BUF0, MIL_RT_BUF1
/// \param subaddress подадрес
/// \param data данные
/// \return результат операции
///
unsigned int mil1553_rt_writeDataToSubaddressTransmit(int fd, unsigned int num_buf, unsigned char subaddress, struct TRtSubaddressData data);

/*-------------------------------------------------------------------------------------------------------*/

/// /// /// /// /// /// /// /// /// ///
/// \remark ОБЩИЕ СЕРВИСНЫЕ ФУНКЦИИ
/// /// /// /// /// /// /// /// /// ///

/// \brief невалидное значение, свидетельствующее об ошибке
#define LIB_BAD_VALUE       0xFFFFFFFF
/// \brief значение отсутсвия ошибки
#define LIB_GOOD            0

///
/// \brief mil1553ud_getNumberChannel получить номер канала из символьного утсройства канала
/// \param fd дескриптор файла
/// \return номер канала
///
unsigned int mil1553ud_getNumberChannel(int fd);

///
/// \brief макрос генериует имя регистра в соответствии с номером канала
/// \param numCh номер канала
/// \param RegName имя регистра без номера канала
///
/// \code
/// unsigned int numCh = mil1553ud_getNumberChannel(fd);
/// unsigned int regAddress = MIL_REG(numCh, CTRL_REG_PCI_CH);
///
#define MIL_REG(numCh, RegName) \
    ( (numCh == CH_NUM_1) ? RegName##1 : ( (numCh == CH_NUM_2) ? RegName##2 : ( (numCh == CH_NUM_3) ? RegName##3 : RegName##4) ) )

/// \remark РАБОТА С КОЛЬЦЕВЫМ БУФЕРОМ ДМА

///
/// \brief mil1553ud_getCountDmaBlocksReadyRead получить количество блоков ДМА, готовых для чтения
/// \param fd дескриптор файла
/// \return кол-во блоков ДМА, готовых к чтению
///
unsigned int mil1553ud_getCountDmaBlocksReadyRead(int fd, unsigned int* codeError);

///
/// \brief mil1553ud_newDmaReadBlock создать контейнер блоков ДМА
/// выделяет под контейнер память
/// \param countDmaBlocks размер контейнера в блоках (штуках)
/// \return указатель на контейнер
///
DMA_READ_BLOCK* mil1553ud_newDmaReadBlock(unsigned int countDmaBlocks);

///
/// \brief mil1553ud_freeDmaReadBlock освобождает контейнер блоков ДМА
/// \param block указатель на контейнер
///
void mil1553ud_freeDmaReadBlock(DMA_READ_BLOCK* block);

///
/// \brief mil1553ud_readAllDmaBlocksReadyRead считывает все блоки ДМА, готовые к чтению, из канала
/// выделяет под контейнер память
/// \param fd дескриптор файла
/// \return указатель на контейнер
///
DMA_READ_BLOCK* mil1553ud_readAllDmaBlocksReadyRead(int fd, unsigned int *cntBlocks);

/// \remark РАБОТА С КОЛЬЦЕВЫМ БУФЕРОМ ПРЕРЫВАНИЙ

///
/// \brief mil1553ud_getCountInterruptBlocksReadyRead получить количество блоков прерываний, готовых для чтения
/// \param fd дескриптор файла
/// \return кол-во блоков, готовых к чтению
///
unsigned int mil1553ud_getCountInterruptBlocksReadyRead(int fd);

///
/// \brief mil1553ud_readInterruptBlocks считывает блоки прерываний, готовые к чтению, из канала
/// \param fd дескриптор файла
/// \param block указатель на контейнер
/// \return результат операции
///
unsigned int mil1553ud_readInterruptBlocks(int fd, INTERRUPT_BLOCK_BUFFER* block);

/// \remark РЕЖИМ КШ

/// \brief действие - останов программы
#define BC_PROGRAM_STOP     0x0u
/// \brief действие - старт программ
#define BC_PROGRAM_START    ~BC_PROGRAM_STOP

///
/// \brief mil1553ud_bcProgram управление микропрограммой в режиме КШ
/// старт/стоп BCSTRT
/// \param fd дескриптор файла
/// \param action действие
///
unsigned int mil1553ud_bcProgram(int fd, unsigned int action);

///
/// \brief mil1553ud_bcSetStartInstructionAddress установить стартовый адрес интсрукции микропрограммы КШ
/// \param fd дескриптор файла
/// \param startNumber стартовый номер (адрес)
///
unsigned int mil1553ud_bcSetStartInstructionAddress(int fd, unsigned int startNumber);

/// \remark РЕЖИМ КШ - РАБОТА С МИКРОПРОГРАММОЙ КШ

///
/// \brief mil1553ud_newBcRamBlock создать контейнер для микропрограммы КШ
/// \param type тип - инструкции, операции, данные
/// MIL_BC_RAM_TYPE_INSTRUCTION, MIL_BC_RAM_TYPE_OPERATION, MIL_BC_RAM_TYPE_DATA
/// \param sizeInDwords размер контейнера в 32-разядных (двойных) словах
/// \param shiftInDwords смещение в памяти КШ в 32-разядных (двойных) словах
/// \return указатель на контейнер для микропрограммы КШ
///
BC_RAM_BLOCK* mil1553ud_newBcRamBlock(unsigned int type, unsigned int sizeInDwords, unsigned int shiftInDwords);

///
/// \brief mil1553ud_freeBcRamBlock освободить контейнер для микропрограммы КШ
/// \param block указатель на контейнер для микропрограммы КШ
///
void mil1553ud_freeBcRamBlock(BC_RAM_BLOCK* block);

/// \remark РЕЖИМ КШ - РАБОТА С МИКРОПРОГРАММОЙ КШ - ИНСТРУКЦИИ, ОПЕРАЦИИ

#define XEQ         0x1
#define XQF         0x15
#define XQG         0x16
#define XFG         0x1E
#define JMP         0x2
#define CAL         0x3
#define RTN         0x4
#define IRQ         0x6
#define HLT         0x7
#define DLY         0x8
#define WFT         0x9
#define CFT         0xA
#define CMT         0xB
#define LTT         0xD
#define LTH         0x18
#define LFT         0xE
#define SFT         0xF
#define WMP         0x1A
#define WMI         0x1C
#define DSZ         0x1D
#define FLG         0xC

#define IDENT       0xA

#define ALWAYS      0xF

///
/// \brief формирование инструкции (32-разрядное слово)
/// \param instruction инструкция
/// \param condition условие
/// \param parameter параметр
///
/// \code
/// unsigned int dword = INSTRUCTION(XEQ, ALWAYS, 0);
///
#define INSTRUCTION(instruction, condition, parameter)   \
    (   \
    ( 0 << 31 ) | ( (instruction & 0x1F) << 26 ) | ( IDENT << 21 ) | ( (condition & 0x1F) << 16) | (parameter & 0xFFFF) \
    )

///
/// \brief нечётная часть операции (32-разрядное слово)
/// \param command команда КШ
/// \param timeout время до начала следующей операции
///
#define OPERATION_ODD_PART(command, timeout)    \
    (   \
    ( (command & 0xFFFF) << 16 ) | (timeout & 0xFFFF)  \
    )

///
/// \brief чётная часть операции (32-разрядное слово)
/// \param cw1 КС1
/// \param parameter параметр
///
#define OPERATION_EVEN_PART(cw1, parameter) \
    (   \
    ( (cw1 & 0xFFFF) << 16 ) | (parameter & 0xFFFF)  \
    )

///
/// \brief командное слово (ГОСТ 52070)
/// \param adrOu адрес ОУ
/// \param k разряд "приём/передача"
/// 0 - ОУ должен принимать СД
/// 1 - ОУ должен передавать СД
/// \param suba_mode подадрес или режим управления
/// \param cntDw_code число СД или код команды
///
#define COMMAND_WORD(adrOu, k, suba_mode, cntDw_code)  \
    (   \
    ( (adrOu & 0x1F) << 11 ) | ( (k & 0x1) << 10) | ( (suba_mode & 0x1F) << 5) | ( (cntDw_code & 0x1F) << 0)   \
    )

/// \remark РАСШИФРОВКА БЛОКОВ ДМА

/// \remark РАСШИФРОВКА БЛОКОВ ДМА - СЕРВИСНЫЕ КОНСТАНТЫ

/// \brief тип блока ДМА - КШ
#define MIL1553UD_BC_DMA_BLOCK      0
/// \brief тип блока ДМА - ОУ
#define MIL1553UD_TD_DMA_BLOCK      1

/// \brief значение FALSE (ложь)
#define MIL1553UD_FALSE             0
/// \brief значение TRUE (истина)
#define MIL1553UD_TRUE              ~(MIL1553UD_FALSE)

/// \brief размер двойного слова в байтах
#define DWORD_SIZE  4
/// \brief размер блока ДМА
#define MIL_DMA_BLOCK_SIZE 128

/// \remark РАСШИФРОВКА БЛОКОВ ДМА - СЕРВИСНЫЕ МАКРОСЫ

/// \brief получить указатель на блок ДМА
#define GET_PTR_DMA_BLOCK(data, numberBlock) \
    data + MIL_DMA_BLOCK_SIZE * numberBlock

/// \brief проверка на допустимость
#define ASSERT_DMA_CONTAINER(ptrContainerDma, numberBlock) \
    (ptrContainerDma == NULL) ? MIL1553UD_FALSE : \
        (numberBlock > ptrContainerDma->countBlocks) ? MIL1553UD_FALSE : MIL1553UD_TRUE

/// \remark РАСШИФРОВКА БЛОКОВ ДМА - ФУНКЦИИ

///
/// \brief mil1553ud_dmaBlock_getTypeTransaction получить тип транзакции из блока ДМА
/// тип транзакции соттветствует значениям 1-10 (см. ГОСТ 52070)
/// \param dmaBlock тип блока ДМА
/// \param dmaBlock указатель на блок ДМА
/// \return тип транзакции
///
unsigned int mil1553ud_dmaBlock_getTypeTransaction(unsigned int typeDmaBlock, unsigned char* dmaBlock);

///
/// \brief mil1553ud_dmaBlock_isSuccessTransaction проверить успешность транзакции
/// \param typeDmaBlock тип блока ДМА
/// \param dmaBlock указатель на блок ДМА
/// \return признак успешности транзакции
///
unsigned int mil1553ud_dmaBlock_isSuccessTransaction(unsigned int typeDmaBlock, unsigned char* dmaBlock);

///
/// \brief mil1553ud_dmaBlock_getFreeTimer получить значение freetimer блока ДМА
/// \param typeDmaBlock тип блока ДМА
/// \param dmaBlock указатель на блок ДМА
/// \return значение freetimer
///
unsigned int mil1553ud_dmaBlock_getFreeTimer(unsigned int typeDmaBlock, unsigned char* dmaBlock);

///
/// \brief mil1553ud_dmaBlock_getCountServiceWords16 получить количество служебных 16-разрядных слов
/// (включая dword 1-5 и служебные слова МКИО)
/// \param typeDmaBlock тип блока ДМА
/// \param dmaBlock указатель на блок ДМА
/// \return количество служебных 16-разрядных слов
///
unsigned int mil1553ud_dmaBlock_getCountServiceWords16(unsigned int typeDmaBlock, unsigned char* dmaBlock);

///
/// \brief mil1553ud_dmaBlock_getCountDataWords16 получить количество 16-разрядных слов данных
/// \param typeDmaBlock тип блока ДМА
/// \param dmaBlock указатель на блок ДМА
/// \return количество 16-разрядных слов данных
///
unsigned int mil1553ud_dmaBlock_getCountDataWords16(unsigned int typeDmaBlock, unsigned char* dmaBlock);

/// \brief Шина "А"
#define MIL1553_BUS_A       0x0
/// \brief Шина "Б"
#define MIL1553_BUS_B       ~MIL1553_BUS_A

///
/// \brief mil1553ud_dmaBlock_getActiveBus получить активную шину
/// (по которой была транзакция)
/// \param typeDmaBlock тип блока ДМА
/// \param dmaBlock указатель на блок ДМА
/// \return шина А или Б
/// MIL1553_BUS_A или MIL1553_BUS_B
///
unsigned int mil1553ud_dmaBlock_getActiveBus(unsigned int typeDmaBlock, unsigned char* dmaBlock);

///
/// \brief mil1553ud_dmaBlock_getPtrDataPart получить указатель на часть с данными блока ДМА
/// \param dmaBlock указатель на блок ДМА
/// \return указатель на часть с данными блока ДМА
///
unsigned char* mil1553ud_dmaBlock_getPtrDataPart(unsigned char* dmaBlock);

///
/// \brief mil1553ud_dmaBlock_tdModeSubaddress получить поддарес из блока ДМА в режиме ОУ
/// \param dmaBlock указатель на блок ДМА
/// \return поддарес
///
unsigned int mil1553ud_dmaBlock_tdModeSubaddress(unsigned char* dmaBlock);

#ifdef __cplusplus
}
#endif

#endif // MIL1553UD_LIBRARY_H
